pub struct InspectPath { /* private fields */ }Expand description
A path through an inspected value tree.
Paths represent navigation from a root value to a specific nested value, using field names and indices.
Examples
use inspect_core::{InspectPath, PathSegment};
let path = InspectPath::new()
.field("users")
.index(2)
.field("name");
assert_eq!(path.to_string(), "users[2].name");Implementations
Sourceimpl InspectPath
impl InspectPath
Sourcepub fn segments(&self) -> &[PathSegment]
pub fn segments(&self) -> &[PathSegment]
Get the segments in this path.